# Config Globals

> **Global** < Model < Model Method
Global
These are the global configuration variables which are defined in Flask.
- They should always be uppercase
- They should always start with `API_`
Values defined here apply globally unless a more specific value is defined.
These values are overridden by Model or Model Method configurations.

## Sections

- [Example](example.md)
